BitReader

Struct BitReader 

pub struct BitReader<'a> { /* private fields */ }
A bit reader for codec bitstreams. It properly handles emulation-prevention bytes and stop bits for H264.

Implementations

Source

impl<'a> BitReader<'a>

pub fn new(data: &'a [u8], needs_epb: bool) -> Self

pub fn read_bit(&mut self) -> Result<bool, String>

Read a single bit from the stream.

pub fn read_bits<U: TryFrom<u32>>( &mut self, num_bits: usize, ) -> Result<U, String>

Read up to 31 bits from the stream. Note that we don’t want to read 32 bits even though we’re returning a u32 because that would break the read_bits_signed() function. 31 bits should be overkill for compressed header parsing anyway.

pub fn read_bits_signed<U: TryFrom<i32>>( &mut self, num_bits: usize, ) -> Result<U, String>

Reads a two’s complement signed integer of length |num_bits|.

pub fn read_bits_aligned<U: TryFrom<u32>>( &mut self, num_bits: usize, ) -> Result<U, String>

Reads an unsigned integer from the stream and checks if the stream is byte aligned.

pub fn skip_bits(&mut self, num_bits: usize) -> Result<(), String>

Skip num_bits bits from the stream.

pub fn num_bits_left(&mut self) -> usize

Returns the amount of bits left in the stream

pub fn num_epb(&self) -> usize

Returns the number of emulation-prevention bytes read so far.

pub fn has_more_rsbp_data(&mut self) -> bool

Whether the stream still has RBSP data. Implements more_rbsp_data(). See the spec for more details.

pub fn read_ue<U: TryFrom<u32>>(&mut self) -> Result<U, String>

Reads an Unsigned Exponential golomb coding number from the next bytes in the bitstream. This may advance the state of position within the bitstream even if the read operation is unsuccessful. See H264 Annex B specification 9.1 for details.

pub fn read_ue_bounded<U: TryFrom<u32>>( &mut self, min: u32, max: u32, ) -> Result<U, String>

pub fn read_ue_max<U: TryFrom<u32>>(&mut self, max: u32) -> Result<U, String>

pub fn read_se<U: TryFrom<i32>>(&mut self) -> Result<U, String>

Reads a signed exponential golomb coding number. Instead of using two’s complement, this scheme maps even integers to positive numbers and odd integers to negative numbers. The least significant bit indicates the sign. See H264 Annex B specification 9.1.1 for details.

pub fn read_se_bounded<U: TryFrom<i32>>( &mut self, min: i32, max: i32, ) -> Result<U, String>

pub fn read_le<U: TryFrom<u32>>(&mut self, num_bits: u8) -> Result<U, String>

Read little endian multi-byte integer.

pub fn position(&self) -> u64

Return the position of this bitstream in bits.